@@ -181,8 +181,8 @@ class Application(aeidon.Observable, metaclass=ApplicationMeta):
             for attr_name in attr_names:
                 attr_value = getattr(agent, attr_name)
                 if attr_name in self._delegations:
-                    raise ValueError("Multiple definitions of {}"
-                                     .format(repr(attr_name)))
+                    raise ValueError("Multiple definitions of {!r}"
+                                     .format(attr_name))
 
                 self._delegations[attr_name] = attr_value
                 # Remove class-level function added by ApplicationMeta.
